@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77manage.c 9656 2012-01-13 18:29:02Z pwessel $
+ *	$Id: mgd77manage.c 9923 2012-12-18 20:45:53Z pwessel $
  *
- *    Copyright (c) 2005-2012 by P. Wessel
+ *    Copyright (c) 2005-2013 by P. Wessel
  * mgd77manage is used to (1) remove data columns from mgd77+ files
  * or (2) add a new data column to mgd77+ files.  Data can be added
  * from data tables, created from reference field formulas, or by
@@ -622,7 +622,7 @@ int main (int argc, char **argv)
 		}
 
 		if (delete) {	/* Must create a new file with everything except the fields to be deleted */
-			GMT_LONG id, c;
+			GMT_LONG id, c, reset_column = FALSE;
 			char oldfile[BUFSIZ];
 			
 			if (column != MGD77_NOT_SET) {	/* Get info about this existing column to see if it is compatible with new data */
@@ -659,6 +659,9 @@ int main (int argc, char **argv)
 				strcat (history, " ");
 				strcat (history, p);
 				n_delete++;
+				if (k == column && c == set) {	/* Just removed the old column by the same name, must unset column */
+					reset_column = TRUE;
+				}
 			}
 			
 			/* Rename the old file for now */
@@ -701,7 +704,10 @@ int main (int argc, char **argv)
 				fprintf (stderr, "%s: Error reading data set for cruise %s\n", GMT_program, list[argno]);
 				exit (EXIT_FAILURE);
 			}
-			n_changed++;
+			if (reset_column)
+				column = MGD77_NOT_SET;
+			else
+				n_changed++;
 		}
 
 		if (got_c == ADD_IGRF) {	/* Append IGRF column */
