@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: xyz2grd.c 9729 2012-03-21 23:19:37Z pwessel $
+ *	$Id: xyz2grd.c 9923 2012-12-18 20:45:53Z pwessel $
  *
- *	Copyright (c) 1991-2012 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2013 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -456,33 +456,33 @@ int main (int argc, char **argv)
 			float value;
 			
 			grd.node_offset = 0;
-			fgets (line, BUFSIZ, fp);
+			(void)fgets (line, BUFSIZ, fp);
 			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (sscanf (line, "%*s %d", &grd.nx) != 1) {
 				fprintf (stderr, "%s: Error decoding ncols record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			fgets (line, BUFSIZ, fp);
+			(void)fgets (line, BUFSIZ, fp);
 			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (sscanf (line, "%*s %d", &grd.ny) != 1) {
 				fprintf (stderr, "%s: Error decoding ncols record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			fgets (line, BUFSIZ, fp);	GMT_str_tolower (line);
+			(void)fgets (line, BUFSIZ, fp);	GMT_str_tolower (line);
 			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (sscanf (line, "%*s %lf", &grd.x_min) != 1) {
 				fprintf (stderr, "%s: Error decoding xll record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
 			if (!strncmp (line, "xllcorner", (size_t)9)) grd.node_offset = 1;	/* Pixel grid */
-			fgets (line, BUFSIZ, fp);	GMT_str_tolower (line);
+			(void)fgets (line, BUFSIZ, fp);	GMT_str_tolower (line);
 			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (sscanf (line, "%*s %lf", &grd.y_min) != 1) {
 				fprintf (stderr, "%s: Error decoding yll record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
 			if (!strncmp (line, "yllcorner", (size_t)9)) grd.node_offset = 1;	/* Pixel grid */
-			fgets (line, BUFSIZ, fp);
+			(void)fgets (line, BUFSIZ, fp);
 			GMT_chop (line);					/* Rid the world of CR/LF */
 			if (sscanf (line, "%*s %lf", &grd.x_inc) != 1) {
 				fprintf (stderr, "%s: Error decoding cellsize record\n", GMT_program);
@@ -500,7 +500,7 @@ int main (int argc, char **argv)
 
 			a = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 			if (!Ctrl->E.set) {	/* Only read if not specified in -E */
-				fgets (line, BUFSIZ, fp);
+				(void)fgets (line, BUFSIZ, fp);
 				GMT_chop (line);					/* Rid the world of CR/LF */
 				if (sscanf (line, "%*s %lf", &Ctrl->E.nodata) != 1) {
 					fprintf (stderr, "%s: Error decoding nodata_value record\n", GMT_program);
